about summary refs log tree commit diff
path: root/editor/pamcomp.c
diff options
context:
space:
mode:
Diffstat (limited to 'editor/pamcomp.c')
-rw-r--r--editor/pamcomp.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/editor/pamcomp.c b/editor/pamcomp.c
index e27b8613..5986de9a 100644
--- a/editor/pamcomp.c
+++ b/editor/pamcomp.c
@@ -80,7 +80,7 @@ parseCommandLine(int                        argc,
    was passed to us as the argv array.  We also trash *argv.
 -----------------------------------------------------------------------------*/
     optEntry *option_def;
         /* Instructions to optParseOptions3 on how to parse our options.
          */
     optStruct3 opt;
 
@@ -114,7 +114,7 @@ parseCommandLine(int                        argc,
     opt.short_allowed = FALSE;  /* We have no short (old-fashioned) options */
     opt.allowNegNum = FALSE;  /* We have no parms that are negative numbers */
 
-    optParseOptions3(&argc, (char **)argv, opt, sizeof(opt), 0);
+    pm_optParseOptions3(&argc, (char **)argv, opt, sizeof(opt), 0);
         /* Uses and sets argc, argv, and some of *cmdlineP and others. */
@@ -80,7 +80,7 @@ parseCommandLine(int                        argc,
 -----------------------------------------------------------------------------*/
     optEntry *option_def;
-        /* Instructions to optParseOptions3 on how to parse our options.
+        /* Instructions to pm_optParseOptions3 on how to parse our options.
          */
     optStruct3 opt;